@@ -1,16 +1,17 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.520-4-gf020794
+package JSON::Schema::Modern; # git description: v0.521-11-g81ca5f58
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.521';
+our $VERSION = '0.522';
 
 use 5.016;  # for fc, unicode_strings features
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
+use experimental 're_strict';
 use strictures 2;
 use JSON::MaybeXS;
 use Carp qw(croak carp);
@@ -221,7 +222,7 @@ sub traverse {
     initial_schema_uri => $base_uri,    # the canonical URI as of the start, or last $id
     schema_path => '',                  # the rest of the path, since the last $id
     errors => [],
-    spec_version => $spec_version,      # can change, iff nothing explicitly requested
+    spec_version => $spec_version,
     vocabularies => [ use_module('JSON::Schema::Modern::Vocabulary::Core') ], # will be filled in later
     identifiers => [],
     configs => {},
@@ -779,7 +780,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.521
+version 0.522
 
 =head1 SYNOPSIS
 
@@ -800,6 +801,8 @@ version of the specification.
 
 =head1 CONFIGURATION OPTIONS
 
+These values are all passed as arguments to the constructor.
+
 =head2 specification_version
 
 Indicates which version of the JSON Schema specification is used during evaluation. When not set,
@@ -1119,7 +1122,7 @@ validation will always succeed):
 
 =item *
 
-C<date-time>, C<date>, and C<time> require L<Time::Moment>
+C<date-time>, C<date>, and C<time> require L<Time::Moment>, L<DateTime::Format::RFC3339>
 
 =item *
 
@@ -1202,7 +1205,9 @@ L<https://json-schema.org/draft/2020-12/release-notes.html>
 
 L<https://json-schema.org/draft/2019-09/release-notes.html>
 
-# L<https://json-schema.org/draft-07/json-schema-release-notes.html>
+=item *
+
+L<https://json-schema.org/draft-07/json-schema-release-notes.html>
 
 =item *
 
