@@ -4,12 +4,13 @@ package JSON::Schema::Modern::Document;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One JSON Schema document
 
-our $VERSION = '0.521';
+our $VERSION = '0.522';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
+use experimental 're_strict';
 use strictures 2;
 use Mojo::URL;
 use Carp 'croak';
@@ -194,7 +195,7 @@ JSON::Schema::Modern::Document - One JSON Schema document
 
 =head1 VERSION
 
-version 0.521
+version 0.522
 
 =head1 SYNOPSIS
 
@@ -223,11 +224,6 @@ When passed in during construction, this represents the initial URI by which the
 be known. It is overwritten with the root schema's C<$id> property when one exists, and as such
 can be considered the canonical URI for the document as a whole.
 
-=head2 specification_version
-
-Indicates which version of the JSON Schema specification is used during evaluation of this schema
-document. Is normally determined automatically at construction time.
-
 =head2 resource_index
 
 An index of URIs to subschemas (JSON pointer to reach the location, and the canonical URI of that
